summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--indra/newview/lldynamictexture.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/lldynamictexture.cpp b/indra/newview/lldynamictexture.cpp
index 800c36f911..87b56f33af 100644
--- a/indra/newview/lldynamictexture.cpp
+++ b/indra/newview/lldynamictexture.cpp
@@ -125,9 +125,9 @@ BOOL LLViewerDynamicTexture::render()
//-----------------------------------------------------------------------------
void LLViewerDynamicTexture::preRender(BOOL clear_depth)
{
- //only images up to 512x512 are supported
- //llassert(mFullHeight <= 512);
- //llassert(mFullWidth <= 512);
+ //only images up to 1024*1024 are supported
+ llassert(mFullHeight <= 1024);
+ llassert(mFullWidth <= 1024);
if (gGLManager.mHasFramebufferObject && gPipeline.mWaterDis.isComplete() && !gGLManager.mIsATI)
{ //using offscreen render target, just use the bottom left corner